@@ -1,5 +1,4 @@
 #
-# $Id: Fasta.pm 16123 2009-09-17 12:57:27Z cjfields $
 #
 # BioPerl module for Bio::Index::Fasta
 #
@@ -106,7 +105,7 @@ Report bugs to the Bioperl bug tracking system to help us keep track
 the bugs and their resolution.  Bug reports can be submitted via the
 web:
 
-  http://bugzilla.open-bio.org/
+  https://redmine.open-bio.org/projects/bioperl/
 
 =head1 AUTHOR - James Gilbert
 
@@ -177,25 +176,21 @@ sub _index_file {
                      # of the last found record.
     );
 
-    $begin = 0;
-
     my $id_parser = $self->id_parser;
 
     open my $FASTA, '<', $file or $self->throw("Can't open file for read : $file");
 
+    my $offset = ( $^O =~ /mswin/i ) ? 1 : 0;
+
     # Main indexing loop
     while (<$FASTA>) {
         if (/^>/) {
             
-            # the following was commented out 9/7/2009 b/c this
-            # breaks FASTA validation - cjfields
+            # the following was fixed to allow validation - cjfields
             
             # $begin is the position of the first character after the '>'
-            #my $offset = ( $^O =~ /mswin/i ) ? 0 : 1;
-            #my $begin = tell($FASTA) - length( $_ ) + $offset;
+            $begin = tell($FASTA) - length( $_ ) - $offset;
             
-            my $begin = tell($FASTA) - length( $_ );
-
             foreach my $id (&$id_parser($_)) {
                 $self->add_record($id, $i, $begin);
             }
